/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/*
 * This class keeps pointers for all images the UI needs, so that they can quickly be accessed from anywhere in the code.
 */

#define _NO_SPRITE_SHORTCUTS_
#include "Images/ImageProvider.h"
#undef _NO_SPRITE_SHORTCUTS_

#include "Images/Image.h"
#include "Images/Drawable.h"
#include "Config.h"

#include "wx/wx.h"

namespace AriaMaestosa {
	
ImagesStruct* images = NULL;

namespace ImageProvider {
    
ImagesStruct* getImages()
{
        
    assert( images != NULL );
        
    return images;
}

void loadImages()
{
	
	assert(images == NULL);
	images=new ImagesStruct();
	
	images -> noteTrackImg=new Image("notetrack.gif");
	images -> noteTrackBackgImg=new Image("notetrack_background.gif");
	images -> sbArrowImg=new Image("sb_arrow.png");
	images -> sbArrowDownImg=new Image("sb_arrow_sel.png");
	images -> sbBackgImg=new Image("sb_backg.png");
	images -> sbBarImg=new Image("sb_bar.tga");
	
	images -> noteTrackDrawable=new Drawable(images -> noteTrackImg);
	images -> noteTrackBackgDrawable=new Drawable(images -> noteTrackBackgImg);
	images -> sbArrowDrawable=new Drawable(images -> sbArrowImg);
	images -> sbBackgDrawable=new Drawable(images -> sbBackgImg);
	images -> sbBarDrawable=new Drawable(images -> sbBarImg);
	
	images -> cornerImg=new Image("corner.jpg");
	images -> borderImg=new Image("border.jpg");
	images -> whiteCornerImg=new Image("white_corner.png");
	images -> whiteBorderImg=new Image("white_border.png");
	images -> collapseImg=new Image("collapse.jpg");
	images -> expandImg=new Image("expand.jpg");
	images -> dockTrackImg=new Image("dock.png");
	images -> muteOnImg=new Image("mute_on.png");
	images -> muteOffImg=new Image("mute_off.png");
	images -> comboBorderImg=new Image("combo_side.png");
	images -> comboBodyImg=new Image("combo_body.png");
	images -> comboSelectImg=new Image("combo_select.png");
	
	images -> cornerDrawable=new Drawable(images -> cornerImg);
	images -> borderDrawable=new Drawable(images -> borderImg);
	images -> whiteCornerDrawable=new Drawable(images -> whiteCornerImg);
	images -> whiteBorderDrawable=new Drawable( images -> whiteBorderImg);
	images -> dockTrackDrawable=new Drawable( images -> dockTrackImg);
	images -> collapseDrawable=new Drawable( images -> collapseImg);
	images -> muteDrawable=new Drawable( images -> muteOffImg);
	images -> comboBorderDrawable=new Drawable( images -> comboBorderImg);
	images -> comboBodyDrawable=new Drawable( images -> comboBodyImg);
	images -> comboSelectDrawable=new Drawable( images -> comboSelectImg);
	
	images -> guitar_viewImg=new Image("guitar_view.jpg");
	images -> keyboard_viewImg=new Image("keyboard_view.jpg");
	images -> score_viewImg=new Image("score_view.jpg");
	images -> drum_viewImg=new Image("drum_view.png");
	images -> controller_viewImg=new Image("controller_view.jpg");
	
	images -> guitar_view=new Drawable( images -> guitar_viewImg);
	images -> keyboard_view=new Drawable( images -> keyboard_viewImg);
	images -> score_view=new Drawable( images -> score_viewImg);
	images -> drum_view=new Drawable( images -> drum_viewImg);
	images -> controller_view=new Drawable( images -> controller_viewImg);
	
	images -> tabImg=new Image("tab_body.png");
	images -> tabBorderImg=new Image("tab_side.png");
	images -> tabDrawable=new Drawable( images -> tabImg);
	images -> tabBorderDrawable=new Drawable( images -> tabBorderImg);
	
	images -> keyGImg=new Image("keyG.png");
	images -> keyG=new Drawable(images -> keyGImg);
	
	images -> noteClosedImg = new Image("noteclosed.png");
    images -> noteClosed = new Drawable(images -> noteClosedImg);
	
	images -> noteOpenImg = new Image("noteopen.png");
    images -> noteOpen = new Drawable(images -> noteOpenImg);
	
	images -> noteTailImg = new Image("notetail.png");
    images -> noteTail = new Drawable(images -> noteTailImg);
}

void unloadImages()
{
	
#ifdef _MORE_DEBUG_CHECKS
	std::cout << "~ImageProvider BEGIN" << std::endl;
#endif
	
	if(images==NULL) return;
	
	

	delete images -> noteTrackImg; images -> noteTrackImg=NULL;
	delete images -> noteTrackBackgImg;
	delete images -> sbArrowImg;
	delete images -> sbArrowDownImg;
	delete images -> sbBackgImg;
	delete images -> sbBarImg;
	
	delete images -> keyGImg;
	delete images -> keyG;
	
	delete images -> noteTrackDrawable;
	delete images -> noteTrackBackgDrawable;
	delete images -> sbArrowDrawable;
	delete images -> sbBackgDrawable;
	delete images -> sbBarDrawable;
	
	delete images -> cornerImg;
	delete images -> borderImg;
	delete images -> whiteCornerImg;
	delete images -> whiteBorderImg;
	delete images -> collapseImg;
	delete images -> expandImg;
	delete images -> muteOnImg;
	delete images -> muteOffImg;
	delete images -> comboBorderImg;
	delete images -> comboBodyImg;
	delete images -> comboSelectImg;
	delete images -> dockTrackImg;
	
	delete images -> tabImg;
	delete images -> tabBorderImg;
	delete images -> tabDrawable;
	delete images -> tabBorderDrawable;
	
	delete images -> cornerDrawable;
	delete images -> borderDrawable;
	delete images -> whiteCornerDrawable;
	delete images -> whiteBorderDrawable;
	delete images -> collapseDrawable;
	delete images -> muteDrawable;
	delete images -> comboBorderDrawable;
	delete images -> comboBodyDrawable;
	delete images -> comboSelectDrawable;
	delete images -> dockTrackDrawable;
	
	delete images -> guitar_viewImg;
	delete images -> keyboard_viewImg;
	delete images -> score_viewImg;
	delete images -> controller_viewImg;
	delete images -> drum_viewImg;
	
	delete images -> guitar_view;
	delete images -> drum_view;
	delete images -> keyboard_view;
	delete images -> score_view;
	delete images -> controller_view;
	
	
	delete images -> noteClosedImg;
    delete images -> noteClosed;
	delete images -> noteOpenImg;
    delete images -> noteOpen;
	delete images -> noteTailImg;
    delete images -> noteTail;
	
	delete images;
	images = NULL;
	
#ifdef _MORE_DEBUG_CHECKS
	std::cout << "~ImageProvider END" << std::endl;
#endif
	
}

bool imagesLoaded()
{
	return images!=NULL;   
}

}

}
